@@ -34,7 +34,7 @@ class OpenCommunitiesViewset(LDPViewSet):
 
     # invalidate cache for every open communities
     # unless /open-communities/ is loaded before /communities/xyz/, the last one will get wrong permission nodes
-    from djangoldp.serializers import invalidate_model_cache_if_has_entry
+    from djangoldp.models import invalidate_model_cache_if_has_entry
     invalidate_model_cache_if_has_entry(self.model)
 
     return queryset
